@@ -17,8 +17,9 @@ try:
     from . import tools, bitreader, cloud_mask, expressions, decision_tree,\
                   filters, indices, batch, algorithms, composite,\
                   manager, utils, collection, oauth, visualization
+    from .tools import array, date, dictionary, ee_list, featurecollection, \
+                       geometry, image, imagecollection, number, string
     from .ui import eprint
-    from .tools.imagecollection import wrapper
     from .batch import Export, Import, Convert, Download
     from .oauth import Initialize
 except ImportError:
