@@ -90,15 +90,22 @@ def isPoint(pointlist):
     else:
         return False
 
+def hasZ(pointlist):
+    """ determine if points inside coordinates have Z values """
+    points = pointlist[0]
+    first = points[0]
+    if len(first) == 3:
+        return True
+    else:
+        return False
 
-def removeZ(pointlist):
-    """ Remove Z value of points if needed """
-    for p in pointlist:
-        if isPoint(p):
-            if len(p) == 3:
-                p.pop(2)
-        else:
-            removeZ(p)
+
+def removeZ(coords):
+    """ Remove Z values from coordinates """
+    newcoords = coords.copy()
+    for p in newcoords[0]:
+        p.pop(2)
+    return newcoords
 
 
 def recrusiveDeleteAsset(assetId):
@@ -144,16 +151,17 @@ def convertDataType(newtype):
     :return: a function to map over a collection
     :rtype: function
     """
+    newtype = newtype.lower()
     def wrap(image):
         TYPES = {'float': image.toFloat,
                  'int': image.toInt,
                  'byte': image.toByte,
                  'double': image.toDouble,
-                 'Uint8': image.toUint8,
+                 'uint8': image.toUint8,
                  'int8': image.toInt8,
-                 'Uint16': image.toUint16,
+                 'uint16': image.toUint16,
                  'int16': image.toInt16,
-                 'Uint32': image.toUint32,
+                 'uint32': image.toUint32,
                  'int32': image.toInt32}
         return TYPES[newtype]()
     return wrap
