@@ -54,15 +54,31 @@ IDS = [
     'LANDSAT/LT04/C01/T1', 'LANDSAT/LT04/C01/T1_TOA', 'LANDSAT/LT04/C01/T1_SR',
     'LANDSAT/LT04/C01/T2', 'LANDSAT/LT04/C01/T2_TOA', 'LANDSAT/LT04/C01/T2_SR',
     'LANDSAT/LT05/C01/T1', 'LANDSAT/LT05/C01/T1_TOA', 'LANDSAT/LT05/C01/T1_SR',
-    'LANDSAT/LT05/C01/T1', 'LANDSAT/LT05/C01/T1_TOA', 'LANDSAT/LT05/C01/T1_SR',
+    'LANDSAT/LT05/C01/T2', 'LANDSAT/LT05/C01/T2_TOA', 'LANDSAT/LT05/C01/T2_SR',
     'LANDSAT/LE07/C01/T1', 'LANDSAT/LE07/C01/T1_TOA', 'LANDSAT/LE07/C01/T1_SR',
     'LANDSAT/LE07/C01/T2', 'LANDSAT/LE07/C01/T2_TOA', 'LANDSAT/LE07/C01/T2_SR',
     'LANDSAT/LC08/C01/T1', 'LANDSAT/LC08/C01/T1_TOA', 'LANDSAT/LC08/C01/T1_SR',
     'LANDSAT/LC08/C01/T2', 'LANDSAT/LC08/C01/T2_TOA', 'LANDSAT/LC08/C01/T2_SR',
 ]
 
+
 class Landsat(Collection):
     """  Landsat Collection """
+    SHORTS = {
+        'LANDSAT/LM01/C01/T1': 'L1', 'LANDSAT/LM01/C01/T2': 'L1T2',
+        'LANDSAT/LM02/C01/T1': 'L2', 'LANDSAT/LM02/C01/T2': 'L2T2',
+        'LANDSAT/LM03/C01/T1': 'L3', 'LANDSAT/LM03/C01/T2': 'L3T2',
+        'LANDSAT/LM04/C01/T1': 'L4MSS', 'LANDSAT/LM04/C01/T2': 'L4MSST2',
+        'LANDSAT/LM05/C01/T1': 'L5MSS', 'LANDSAT/LM05/C01/T2': 'L5MSST2',
+        'LANDSAT/LT04/C01/T1': 'L4RAW', 'LANDSAT/LT04/C01/T1_TOA': 'L4TOA', 'LANDSAT/LT04/C01/T1_SR':'L4SR',
+        'LANDSAT/LT04/C01/T2': 'L4RAWT2', 'LANDSAT/LT04/C01/T2_TOA': 'L4TOAT2', 'LANDSAT/LT04/C01/T2_SR': 'L4SRT2',
+        'LANDSAT/LT05/C01/T1': 'L5RAW', 'LANDSAT/LT05/C01/T1_TOA': 'L5TOA', 'LANDSAT/LT05/C01/T1_SR': 'L5SR',
+        'LANDSAT/LT05/C01/T2': 'L5RAWT2', 'LANDSAT/LT05/C01/T2_TOA': 'L5TOAT2', 'LANDSAT/LT05/C01/T2_SR': 'L5SRT2',
+        'LANDSAT/LE07/C01/T1': 'L7RAW', 'LANDSAT/LE07/C01/T1_TOA': 'L7TOA', 'LANDSAT/LE07/C01/T1_SR': 'L7SR',
+        'LANDSAT/LE07/C01/T2': 'L7RAWT2', 'LANDSAT/LE07/C01/T2_TOA': 'L7TOAT2', 'LANDSAT/LE07/C01/T2_SR': 'L7SRT2',
+        'LANDSAT/LC08/C01/T1': 'L8RAW', 'LANDSAT/LC08/C01/T1_TOA': 'L8TOA', 'LANDSAT/LC08/C01/T1_SR': 'L8SR',
+        'LANDSAT/LC08/C01/T2': 'L8RAWT2', 'LANDSAT/LC08/C01/T2_TOA': 'L8TOAT2', 'LANDSAT/LC08/C01/T2_SR': 'L8SRT2',
+    }
 
     def __init__(self, number, process=None, sensor=None, tier=1):
         """ Landsat Collection
@@ -111,6 +127,22 @@ class Landsat(Collection):
         # BANDS
         self._bands = self._make_bands()
 
+        self.short_name = self.SHORTS.get(self.id)
+
+        # COMMON MASKS
+        if self.sensor == 'MSS':
+            self.common_masks = [self.bqa_mss]
+        if self.number in [4,5,7]:
+            if self.process == 'SR':
+                self.common_masks = [self.pixel_qa, self.sr_cloud_qa]
+            elif self.process in ['RAW', 'TOA']:
+                self.common_masks = [self.bqa]
+        if self.number == 8:
+            if self.process == 'SR':
+                self.common_masks = [self.pixel_qa]
+            elif self.process in ['TOA', 'RAW']:
+                self.common_masks = [self.bqa]
+
     @staticmethod
     def fromId(id):
         """ Create a Landsat class from a GEE ID """
@@ -357,6 +389,37 @@ class Landsat(Collection):
 
         return [b for b in band if b]
 
+    def bqa_mss(self, image, classes=('cloud',), renamed=False):
+        if renamed:
+            band = 'bqa'
+        else:
+            band = 'BQA'
+
+        return self.applyMask(image, band, classes, renamed)
+
+    def sr_cloud_qa(self, image, classes=('cloud', 'shadow', 'snow'), renamed=False):
+        if renamed:
+            band = 'cloud_qa'
+        else:
+            band = 'sr_cloud_qa'
+
+        return self.applyMask(image, band, classes, renamed)
+
+    def pixel_qa(self, image, classes=('shadow', 'cloud', 'snow'), renamed=False):
+        for clas in classes:
+            if clas in ['clear', 'water']:
+                image = self.applyPositiveMask(image, 'pixel_qa', [clas], renamed)
+            else:
+                image = self.applyMask(image, 'pixel_qa', [clas], renamed)
+        return image
+
+    def bqa(self, image, classes=('cloud', 'shadow', 'snow'), renamed=False):
+        if renamed:
+            band = 'bqa'
+        else:
+            band = 'BQA'
+        return self.applyMask(image, band, classes, renamed)
+
     def harmonize(self, image, renamed=False):
         """ HARMONIZATION """
         options = ['blue', 'green', 'red', 'nir', 'swir', 'swir2']
